Psono
=====

`Psono <https://psono.com/>`__ is documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/playbooks/psono/roles/psono/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/group_vars/psono-service-group.yml`
file.

The service is created with:

.. code::

    $ enough --domain example.com service create psono
